mtd/include/linux/mtd nand.h,1.60,1.61

dbrown at infradead.org dbrown at infradead.org
Thu Jun 24 08:39:38 EDT 2004


Update of /home/cvs/mtd/include/linux/mtd
In directory phoenix.infradead.org:/tmp/cvs-serv14125/include/linux/mtd

Modified Files:
	nand.h 
Log Message:
Add ability to use a larger (virtual) eraseblock size for BBT tables.


Index: nand.h
===================================================================
RCS file: /home/cvs/mtd/include/linux/mtd/nand.h,v
retrieving revision 1.60
retrieving revision 1.61
diff -u -r1.60 -r1.61
--- nand.h	22 Jun 2004 19:19:53 -0000	1.60
+++ nand.h	24 Jun 2004 12:39:36 -0000	1.61
@@ -247,7 +247,8 @@
  * @wq:			[INTERN] wait queue to sleep on if a NAND operation is in progress
  * @state: 		[INTERN] the current state of the NAND device
  * @page_shift:		[INTERN] number of address bits in a page (column address bits)
  * @erase_shift:	[INTERN] number of address bits in an eraseblock
  * @chip_shift:		[INTERN] number of address bits in one chip
  * @data_buf:		[INTERN] internal buffer for one page + oob 
  * @oob_buf:		[INTERN] oob buffer for one eraseblock
@@ -299,7 +300,8 @@
 	wait_queue_head_t wq;
 	nand_state_t 	state;
 	int 		page_shift;
-	int		erase_shift;
+	int		phys_erase_shift;
+	int		bbt_erase_shift;
 	int		chip_shift;
 	u_char 		*data_buf;
 	u_char		*oob_buf;
@@ -247,7 +247,8 @@
  * @state: 		[INTERN] the current state of the NAND device
  * @page_shift:		[INTERN] number of address bits in a page (column address bits)
- * @erase_shift:	[INTERN] number of address bits in an eraseblock
+ * @phys_erase_shift:	[INTERN] number of address bits in a physical eraseblock
+ * @bbt_erase_shift:	[INTERN] number of address bits in a bbt entry
  * @chip_shift:		[INTERN] number of address bits in one chip
  * @data_buf:		[INTERN] internal buffer for one page + oob 





More information about the linux-mtd-cvs mailing list